@@ -23,10 +23,13 @@ from django.urls import path, reverse_lazy
 from django.views.generic import RedirectView
 
 urlpatterns = [
-    path(r'^$', RedirectView.as_view(url=reverse_lazy('list_index'), permanent=True)),
-    path(r'^mailman3/', include('postorius.urls')),
-    path(r'^archives/', include('hyperkitty.urls')),
-    path(r'', include('django_mailman3.urls')),
-    path(r'^accounts/', include('allauth.urls')),
-    path(r'^admin/', admin.site.urls),
+    path(
+        '',
+        RedirectView.as_view(url=reverse_lazy('list_index'), permanent=True),
+    ),
+    path('mailman3/', include('postorius.urls')),
+    path('archives/', include('hyperkitty.urls')),
+    path('', include('django_mailman3.urls')),
+    path('accounts/', include('allauth.urls')),
+    path('admin/', admin.site.urls),
 ]
